summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/compiler/scala/tools/nsc/ast/parser/Parsers.scala8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/compiler/scala/tools/nsc/ast/parser/Parsers.scala b/src/compiler/scala/tools/nsc/ast/parser/Parsers.scala
index d81b31904c..3637a8f050 100644
--- a/src/compiler/scala/tools/nsc/ast/parser/Parsers.scala
+++ b/src/compiler/scala/tools/nsc/ast/parser/Parsers.scala
@@ -92,8 +92,8 @@ trait Parsers {
private def stringVal = inName.toString
private def inNextTokenCode = in.next.token
- /** whether a non-continuable error has been seen */
- private var nonContinuableError = false
+ /** whether a non-continuable syntax error has been seen */
+ private var syntaxErrorSeen = false
/** the markup parser */
def xmlp = {
@@ -181,7 +181,7 @@ trait Parsers {
skip()
in.skipping = false
}
- nonContinuableError = true
+ syntaxErrorSeen = true
}
def syntaxErrorMigrate(msg: String) =
@@ -196,7 +196,7 @@ trait Parsers {
def incompleteInputError(pos: ScanPosition, msg: String) {
if (pos == in.errpos) return
- if (nonContinuableError)
+ if (syntaxErrorSeen)
syntaxError(pos, msg, false)
else {
in.incompleteInputError(pos, msg)